library(psych)

#################################
#Egyszempontos ANOVA
#################################

data("PlantGrowth")
summary(PlantGrowth)

#Normalitas vizsgalata, eloszlas elemzese 
shapiro.test(PlantGrowth$weight)

plot(density(PlantGrowth$weight))

hist(PlantGrowth$weight)
hist(PlantGrowth$weight,
     main="Plant weight",
     xlab="Weight - kg",
     xlim=c(3.5,7),
     col="darkmagenta",
     freq=TRUE
)

#ANOVA
plant_aov <- aov(PlantGrowth$weight~PlantGrowth$group)
summary(plant_aov)

#Post-hoc elemzes a csoportkepzo ismerv egyes ertekeire
TukeyHSD(plant_aov)
plot(TukeyHSD(plant_aov))

#################################
#Tbbszempontos ANOVA
#################################

data("OrchardSprays")
summary(OrchardSprays)

#Normalitas vizsgalata, eloszlas elemzese
plot(density(OrchardSprays$decrease))

shapiro.test(OrchardSprays$decrease)

#ANOVA
orchard_aov <- aov(OrchardSprays$decrease~OrchardSprays$treatment+OrchardSprays$rowpos)
summary(orchard_aov)

#ANOVA interakcios hatassal (*)
orchard_aov_all <- aov(OrchardSprays$decrease~OrchardSprays$treatment*OrchardSprays$rowpos)
summary(orchard_aov_all)

#################################
#Linearis regresszio
#################################

library(psych)
data(epi.bfi)

#Normalitas vizsgalata, eloszlas elemzese
shapiro.test(epi.bfi$epiNeur)
shapiro.test(epi.bfi$bfneur)

plot(density(epi.bfi$epiNeur))
plot(density(epi.bfi$bfneur))

var.test(epi.bfi$bfneur,epi.bfi$epiNeur)
t.test(epi.bfi$bfneur,epi.bfi$epiNeur)

#Egyvaltozos linearis regresszio epiNeur valtozoval
lin_reg <- lm(epi.bfi$bdi~epi.bfi$epiNeur)
summary(lin_reg)

# opcionalis elrendezes 4 graphs/page
layout(matrix(c(1,2,3,4),2,2)) # optional 4 graphs/page
plot(lin_reg)

#Egyvaltozos linearis regresszio bfagree valtozoval
lin_reg2 <- lm(epi.bfi$bdi ~ epi.bfi$bfagree)
summary(lin_reg2)

#Tobbvaltozos linearis regresszio
lin_reg_multi <- lm(epi.bfi$bdi ~ epi.bfi$bfagree + epi.bfi$epiNeur)
summary(lin_reg_multi)

#Tobbvaltozos linearis regresszio interakcioval
lin_reg_multi <- lm(epi.bfi$bdi ~ epi.bfi$bfagree * epi.bfi$epiNeur)
summary(lin_reg_multi)


##########################
#Fuggosegek vizsgalata
##########################

library("gplots") 
Result <- table(sat.act$gender,sat.act$education)
balloonplot(t(Result), main ="Dependency between gender and education", xlab ="", ylab="", label = FALSE, show.margins = FALSE)

library("graphics") 
mosaicplot(Result , shade = TRUE, las=2, main = " Dependency between gender and education ")

#round(Chisq_res$residuals, 3)

#Elrendezes visszaallitasa alaphelyzetbe
layout.show(n = 1)

library(psych)
data(sat.act)
chisq.test(sat.act$gender,sat.act$education)
library(corrplot)
corrplot(Chisq_res$residuals, is.cor = FALSE)

library(coin)
tabla <- table(sat.act$gender,sat.act$education)
chisq_test(tabla)


##########################
#Korrelacio
##########################
cor.test( ~ gender + education,
          data=sat.act,
          method = "spearman",
          continuity = FALSE,
          conf.level = 0.05)

cor.test(korrelacio$Magassag,korrelacio$Tomeg)

#Pearson-fele linearis korrelacio
with(korrelacio,cor.test(Szul_tomeg,Tomeg))
with(korrelacio,cor.test(Szul_hossz,Tomeg))
with(korrelacio,cor.test(Szul_hossz,Magassag))

#Spearman Rangkorrelacio
with(korrelacio,cor.test(Szul_tomeg,Tomeg, method = "spearman"))

#Kendall Rangkorrelacio
with(korrelacio,cor.test(Szul_tomeg,Tomeg, method = "kendall"))


#############################################################
#Regresszio - tovabbi peldak a "korrelacio" nevu adathalmazon
#############################################################

#linearis regresszio
regr_m = lm(Tomeg ~ Szul_tomeg, data = korrelacio)
summary(regr_m)

layout(1)
with(korrelacio,plot(Tomeg ~ Szul_tomeg, pch = 20, xlab="szuleteskori tomeg (g)", ylab="Testtomeg (kg)" ))
abline(regr_m,lty=2)

#tobbszoros linearis regresszio
regr_m2 = lm(Tomeg ~ Szul_tomeg + Magassag, data = korrelacio)
summary(regr_m2)

regr_m3 = lm(Tomeg ~ Szul_tomeg + Szul_hossz, data = korrelacio)
summary(regr_m3)


################################
#Teljes es parcialis korrelacio
################################

correlation_full = cor(korrelacio, use= "complete.obs")
library(corrplot)
corrplot(correlation_full)

library(corpcor)
correlation_partial = cor2pcor(correlation_full)
corrplot(correlation_partial)

layout(2,2)
corrplot(correlation_full)
corrplot(correlation_partial)

